==> odps-center-api-1.1.79-20231017.031658-3-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerActJoinDetailDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者积分商城活动参与数据接口回传
 */
public class DuibaPartnerActJoinDetailDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * app_id
     */
    private String appId;

    /**
     * 兑吧客户id
     */
    private String consumerId;

    /**
     * 开发者客户id
     */
    private Long partnerUserId;

    /**
     * 兑吧活动id
     */
    private String duibaActivityId;

    /**
     * 开发者活动id
     */
    private String operatingActivityId;

    /**
     * 活动名称
     */
    private String actName;

    /**
     * 消耗积分数
     */
    private Long consumeCredits;

    /**
     * 中奖奖品id
     */
    private String activityOptionId;

    /**
     * 中奖奖品名称
     */
    private String activityOptionName;

    /**
     * 参与时间
     */
    private String joinTime;

    /**
     * 参与流水id
     */
    private Long joinFlowId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppId() {
        return appId;
    }

    public void setConsumerId(String consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerId() {
        return consumerId;
    }

    public void setPartnerUserId(Long partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getPartnerUserId() {
        return partnerUserId;
    }

    public void setDuibaActivityId(String duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public String getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setOperatingActivityId(String operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public String getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setActName(String actName) {
        this.actName = actName;
    }

    public String getActName() {
        return actName;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setActivityOptionId(String activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setJoinTime(String joinTime) {
        this.joinTime = joinTime;
    }

    public String getJoinTime() {
        return joinTime;
    }

    public void setJoinFlowId(Long joinFlowId) {
        this.joinFlowId = joinFlowId;
    }

    public Long getJoinFlowId() {
        return joinFlowId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> odps-center-api-1.3.58-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerActJoinDetailDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者积分商城活动参与数据接口回传
 */
public class DuibaPartnerActJoinDetailDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * app_id
     */
    private String appId;

    /**
     * 兑吧客户id
     */
    private String consumerId;

    /**
     * 开发者客户id
     */
    private String partnerUserId;

    /**
     * 兑吧活动id
     */
    private String duibaActivityId;

    /**
     * 开发者活动id
     */
    private String operatingActivityId;

    /**
     * 活动名称
     */
    private String actName;

    /**
     * 消耗积分数
     */
    private Long consumeCredits;

    /**
     * 中奖奖品id
     */
    private String activityOptionId;

    /**
     * 中奖奖品名称
     */
    private String activityOptionName;

    /**
     * 参与时间
     */
    private String joinTime;

    /**
     * 参与流水id
     */
    private Long joinFlowId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppId() {
        return appId;
    }

    public void setConsumerId(String consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerId() {
        return consumerId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setDuibaActivityId(String duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public String getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setOperatingActivityId(String operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public String getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setActName(String actName) {
        this.actName = actName;
    }

    public String getActName() {
        return actName;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setActivityOptionId(String activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setJoinTime(String joinTime) {
        this.joinTime = joinTime;
    }

    public String getJoinTime() {
        return joinTime;
    }

    public void setJoinFlowId(Long joinFlowId) {
        this.joinFlowId = joinFlowId;
    }

    public Long getJoinFlowId() {
        return joinFlowId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}
